@@ -1,13 +1,13 @@
 package Log::Any::For::Builtins;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 use Log::Any '$log';
 use SHARYANTO::String::Util qw(ellipsis);
 use SHARYANTO::Proc::ChildError qw(explain_child_error);
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 our $Max_Log_Output = 1024;
 
@@ -18,7 +18,7 @@ sub system {
     my $res = CORE::system(@_);
     if ($log->is_trace) {
         $log->tracef("system() child error: %d (%s)",
-                     $?, explain_child_error($?)) if $?;
+                     $?, explain_child_error()) if $?;
     }
     $res;
 }
@@ -34,7 +34,7 @@ sub my_qx {
     if ($wa) { @output = qx($arg) } else { $output = qx($arg) }
     if ($log->is_trace) {
         $log->tracef("my_qx() child error: %d (%s)",
-                     $?, explain_child_error($?)) if $?;
+                     $?, explain_child_error()) if $?;
         if ($wa) { $output = join("", @output) }
         $log->tracef("my_qx() output (%d bytes%s): %s",
                      length($output),
@@ -65,17 +65,19 @@ sub import {
 1;
 # ABSTRACT: Log builtin functions
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Any::For::Builtins - Log builtin functions
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -119,16 +121,31 @@ L<Log::Any>
 
 Other Log::Any::For::* modules.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Builtin-Logged>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Builtin-Logged>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Builtin-Logged>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
